@@ -18,22 +18,30 @@ ploturl <- function(jobid, plottype = "", token = NULL) {
     headers <- c(headers, "Authorization" = paste("Bearer", token))
   }
 
-  tryCatch({
-    res <- GET(
-      url = paste0("https://pcats.research.cchmc.org/api/job/", jobid, "/ploturl"),
-      add_headers(headers)
-    )
-  }, error = function(e) {
-    return(NULL)  # Catch connection errors
-  })
+  retry_count <- 5
+  while(1) {
+    output <- tryCatch({
+      res <- GET(
+        url = paste0("https://pcats.research.cchmc.org/api/job/", jobid, "/ploturl"),
+        add_headers(headers)
+      )
+      if (res$status_code != 200) {
+        return(NULL)
+      }
+  
+      url <- jsonlite::fromJSON(httr::content(res, as = "text"))
+      output <- paste0(url$url, plottype)
+      output
+    }, error = function(e) {
+      return(NULL)  # Catch connection errors
+    })
+    if (output != "") break;
 
-  if (res$status_code != 200) {
-    return(NULL)
+    retry_count <- retry_count - 1
+    if (retry_count == 0) break;
+    Sys.sleep(1)
   }
 
-  url <- jsonlite::fromJSON(httr::content(res, as = "text"))
-
   # url<-jsonlite::fromJSON(paste0("https://pcats.research.cchmc.org/api/job/",jobid,"/ploturl"))
-  output <- paste0(url$url, plottype)
   output
 }
